@@ -111,11 +111,11 @@ public class SimpleArtifactRepositoryTest extends AbstractProvisioningTest {
 		File files[] = repositoryFile.listFiles();
 		boolean jarFilePresent = false;
 		boolean artifactFilePresent = false;
-		for (int i = 0; i < files.length; i++) {
-			if ("artifacts.jar".equalsIgnoreCase(files[i].getName())) {
+		for (File file : files) {
+			if ("artifacts.jar".equalsIgnoreCase(file.getName())) {
 				jarFilePresent = true;
 			}
-			if ("artifacts.xml".equalsIgnoreCase(files[i].getName())) {
+			if ("artifacts.xml".equalsIgnoreCase(file.getName())) {
 				artifactFilePresent = false;
 			}
 		}
@@ -144,11 +144,11 @@ public class SimpleArtifactRepositoryTest extends AbstractProvisioningTest {
 		File files[] = repositoryFile.listFiles();
 		boolean jarFilePresent = false;
 		boolean artifactFilePresent = false;
-		for (int i = 0; i < files.length; i++) {
-			if ("artifacts.jar".equalsIgnoreCase(files[i].getName())) {
+		for (File file : files) {
+			if ("artifacts.jar".equalsIgnoreCase(file.getName())) {
 				jarFilePresent = true;
 			}
-			if ("artifacts.xml".equalsIgnoreCase(files[i].getName())) {
+			if ("artifacts.xml".equalsIgnoreCase(file.getName())) {
 				artifactFilePresent = true;
 			}
 		}
@@ -474,24 +474,39 @@ public class SimpleArtifactRepositoryTest extends AbstractProvisioningTest {
 		System.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "2");
 		assertEquals("Valid User setting", 2, getIntVal(getMaximumThreads, repo));
 
-		// User value is too high
+		// User value is high, but repo specifies no limit, so user value is used
+		// directly.
 		System.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "22");
-		assertEquals("Invalid User setting", defaultMaxThreads, getIntVal(getMaximumThreads, repo));
+		assertEquals("Invalid User setting", 22, getIntVal(getMaximumThreads, repo));
 		System.clearProperty(SimpleArtifactRepository.PROP_MAX_THREADS);
 
 		// Legitimate repo value
 		repo.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "4");
 		assertEquals("Valid repository specified setting", 4, getIntVal(getMaximumThreads, repo));
 
+		// Legitimate big repo value, but user default when not specified at all is 4.
+		repo.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "8");
+		assertEquals("Valid repository specified setting", 4, getIntVal(getMaximumThreads, repo));
+
 		// User value is lower should take precedence
 		repo.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "3");
 		System.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "2");
 		assertEquals("User setting should take precedence", 2, getIntVal(getMaximumThreads, repo));
 
-		// User value is lower should take precedence
+		// User value is big but lower should take precedence
+		repo.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "10");
+		System.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "8");
+		assertEquals("User setting should take precedence", 8, getIntVal(getMaximumThreads, repo));
+
+		// Repo value is lower should take precedence
 		repo.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "2");
 		System.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "3");
 		assertEquals("User setting should take precedence", 2, getIntVal(getMaximumThreads, repo));
+
+		// Repo value is big but lower should take precedence
+		repo.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "8");
+		System.setProperty(SimpleArtifactRepository.PROP_MAX_THREADS, "10");
+		assertEquals("User setting should take precedence", 8, getIntVal(getMaximumThreads, repo));
 	}
 
 	private int getIntVal(Method m, Object repo) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException {
