@@ -15,7 +15,7 @@
 package org.eclipse.equinox.p2.tests.director;
 
 import static org.hamcrest.CoreMatchers.containsString;
-import static org.junit.Assert.assertThat;
+import static org.hamcrest.MatcherAssert.assertThat;
 
 import java.io.File;
 import java.io.PrintStream;
