@@ -583,8 +583,7 @@ public class ProfileRegistryTest extends AbstractProvisioningTest {
 		try {
 			IInstallableUnit engineIU = createEclipseIU("org.eclipse.equinox.p2.engine", Version.create("55.2"));
 			final String[] values = new String[] {"", "blort", null, EngineActivator.PROFILE_FORMAT_UNCOMPRESSED};
-			for (int i = 0; i < values.length; i++) {
-				final String currentValue = values[i];
+			for (String currentValue : values) {
 				if (currentValue == null)
 					System.getProperties().remove(EngineActivator.PROP_PROFILE_FORMAT);
 				else
@@ -678,9 +677,9 @@ public class ProfileRegistryTest extends AbstractProvisioningTest {
 		assertEquals(3, timestamps.length);
 		int fail = 0;
 
-		for (int i = 0; i < timestamps.length; i++) {
+		for (long timestamp : timestamps) {
 			try {
-				registry.removeProfile(PROFILE_NAME, timestamps[i]);
+				registry.removeProfile(PROFILE_NAME, timestamp);
 			} catch (ProvisionException e) {
 				fail++;
 			}
