@@ -95,8 +95,7 @@ public class ConfigCUsActionTest extends ActionTest {
 	private void verifyFragment(String cuType) {
 		ArrayList<IInstallableUnit> IUs = new ArrayList<>(publisherResult.getIUs(null, IPublisherResult.NON_ROOT));
 		assertTrue(IUs.size() == 2);
-		for (int i = 0; i < IUs.size(); i++) {
-			InstallableUnit iu = (InstallableUnit) IUs.get(i);
+		for (IInstallableUnit iu : IUs) {
 			if (iu.getId().equals(flavor + id + "." + cuType + "." + configSpec)) { //$NON-NLS-1$ //$NON-NLS-2$
 				assertTrue(iu.getFilter().equals(InstallableUnit.parseFilter("(& (osgi.ws=win32)(osgi.os=win32)(osgi.arch=x86))"))); //$NON-NLS-1$
 				assertTrue(iu.getVersion().equals(version));
@@ -123,9 +122,9 @@ public class ConfigCUsActionTest extends ActionTest {
 		ITouchpointData data = touchpointData.iterator().next();
 		ITouchpointInstruction instruction = data.getInstruction("configure");
 		String body = instruction.getBody();
-		assertTrue("arg -foo bar", body.indexOf("addProgramArg(programArg:-foo bar);") > -1);
-		assertTrue("vmarg -agentlib", body.indexOf("addJvmArg(jvmArg:-agentlib${#58}jdwp=transport=dt_socket${#44}server=y${#44}suspend=n${#44}address=8272);") > -1);
-		assertTrue("arg -product com,ma", body.indexOf("addProgramArg(programArg:-product);addProgramArg(programArg:com${#44}ma);") > -1);
+		assertTrue("arg -foo bar", body.contains("addProgramArg(programArg:-foo bar);"));
+		assertTrue("vmarg -agentlib", body.contains("addJvmArg(jvmArg:-agentlib${#58}jdwp=transport=dt_socket${#44}server=y${#44}suspend=n${#44}address=8272);"));
+		assertTrue("arg -product com,ma", body.contains("addProgramArg(programArg:-product);addProgramArg(programArg:com${#44}ma);"));
 	}
 
 	private void verifyConfigProperties(IInstallableUnit iu) {
@@ -134,9 +133,9 @@ public class ConfigCUsActionTest extends ActionTest {
 		ITouchpointData data = touchpointData.iterator().next();
 		ITouchpointInstruction instruction = data.getInstruction("configure");
 		String body = instruction.getBody();
-		assertTrue("eclipse.product", body.indexOf("setProgramProperty(propName:eclipse.product,propValue:org.eclipse.platform.ide);") > -1);
-		assertTrue("eclipse.buildId", body.indexOf("setProgramProperty(propName:eclipse.buildId,propValue:TEST-ID);") > -1);
-		assertTrue("my.property", body.indexOf("setProgramProperty(propName:my.property,propValue:${#123}a${#44}b${#58}c${#59}${#36}d${#125});") > -1);
+		assertTrue("eclipse.product", body.contains("setProgramProperty(propName:eclipse.product,propValue:org.eclipse.platform.ide);"));
+		assertTrue("eclipse.buildId", body.contains("setProgramProperty(propName:eclipse.buildId,propValue:TEST-ID);"));
+		assertTrue("my.property", body.contains("setProgramProperty(propName:my.property,propValue:${#123}a${#44}b${#58}c${#59}${#36}d${#125});"));
 	}
 
 	@Override
