@@ -90,9 +90,10 @@ public class RemoveSourceBundleActionTest extends AbstractProvisioningTest {
 	private boolean inBundles(SourceManipulator manipulator, File osgiTarget) throws IOException {
 		URI location = osgiTarget.toURI();
 		BundleInfo[] bundles = manipulator.getBundles();
-		for (int i = 0; i < bundles.length; i++) {
-			if (location.equals(bundles[i].getLocation()))
+		for (BundleInfo bundle : bundles) {
+			if (location.equals(bundle.getLocation())) {
 				return true;
+			}
 		}
 		return false;
 	}
