@@ -1,9 +1,12 @@
 /*******************************************************************************
  *  Copyright (c) 2000, 2017 IBM Corporation and others.
- *  All rights reserved. This program and the accompanying materials
- *  are made available under the terms of the Eclipse Public License v1.0
+ *
+ *  This program and the accompanying materials
+ *  are made available under the terms of the Eclipse Public License 2.0
  *  which accompanies this distribution, and is available at
- *  http://www.eclipse.org/legal/epl-v10.html
+ *  https://www.eclipse.org/legal/epl-2.0/
+ *
+ *  SPDX-License-Identifier: EPL-2.0
  * 
  *  Contributors:
  *     IBM Corporation - initial API and implementation
@@ -377,83 +380,115 @@ public class DefaultSiteParser extends DefaultHandler {
 	}
 
 	private void handleCategoryDefState(String elementName, Attributes attributes) {
-		if (elementName.equals(FEATURE)) {
-			stateStack.push(Integer.valueOf(STATE_FEATURE));
-			processFeature(attributes);
-		} else if (elementName.equals(BUNDLE)) {
-			stateStack.push(Integer.valueOf(STATE_BUNDLE));
-			processBundle(attributes);
-		} else if (elementName.equals(ARCHIVE)) {
-			stateStack.push(Integer.valueOf(STATE_ARCHIVE));
-			processArchive(attributes);
-		} else if (elementName.equals(CATEGORY_DEF)) {
-			stateStack.push(Integer.valueOf(STATE_CATEGORY_DEF));
-			processCategoryDef(attributes);
-		} else if (elementName.equals(DESCRIPTION)) {
-			stateStack.push(Integer.valueOf(STATE_DESCRIPTION_CATEGORY_DEF));
-			processInfo(attributes);
-		} else
-			internalErrorUnknownTag(NLS.bind(Messages.DefaultSiteParser_UnknownElement, (new String[] {elementName, getState(currentState)})));
+		switch (elementName) {
+			case FEATURE:
+				stateStack.push(Integer.valueOf(STATE_FEATURE));
+				processFeature(attributes);
+				break;
+			case BUNDLE:
+				stateStack.push(Integer.valueOf(STATE_BUNDLE));
+				processBundle(attributes);
+				break;
+			case ARCHIVE:
+				stateStack.push(Integer.valueOf(STATE_ARCHIVE));
+				processArchive(attributes);
+				break;
+			case CATEGORY_DEF:
+				stateStack.push(Integer.valueOf(STATE_CATEGORY_DEF));
+				processCategoryDef(attributes);
+				break;
+			case DESCRIPTION:
+				stateStack.push(Integer.valueOf(STATE_DESCRIPTION_CATEGORY_DEF));
+				processInfo(attributes);
+				break;
+			default:
+				internalErrorUnknownTag(NLS.bind(Messages.DefaultSiteParser_UnknownElement, (new String[] {elementName, getState(currentState)})));
+				break;
+		}
 	}
 
 	private void handleCategoryState(String elementName, Attributes attributes) {
-		if (elementName.equals(DESCRIPTION)) {
-			stateStack.push(Integer.valueOf(STATE_DESCRIPTION_SITE));
-			processInfo(attributes);
-		} else if (elementName.equals(FEATURE)) {
-			stateStack.push(Integer.valueOf(STATE_FEATURE));
-			processFeature(attributes);
-		} else if (elementName.equals(BUNDLE)) {
-			stateStack.push(Integer.valueOf(STATE_BUNDLE));
-			processBundle(attributes);
-		} else if (elementName.equals(ARCHIVE)) {
-			stateStack.push(Integer.valueOf(STATE_ARCHIVE));
-			processArchive(attributes);
-		} else if (elementName.equals(CATEGORY_DEF)) {
-			stateStack.push(Integer.valueOf(STATE_CATEGORY_DEF));
-			processCategoryDef(attributes);
-		} else if (elementName.equals(CATEGORY)) {
-			stateStack.push(Integer.valueOf(STATE_CATEGORY));
-			processCategory(attributes);
-		} else
-			internalErrorUnknownTag(NLS.bind(Messages.DefaultSiteParser_UnknownElement, (new String[] {elementName, getState(currentState)})));
+		switch (elementName) {
+			case DESCRIPTION:
+				stateStack.push(Integer.valueOf(STATE_DESCRIPTION_SITE));
+				processInfo(attributes);
+				break;
+			case FEATURE:
+				stateStack.push(Integer.valueOf(STATE_FEATURE));
+				processFeature(attributes);
+				break;
+			case BUNDLE:
+				stateStack.push(Integer.valueOf(STATE_BUNDLE));
+				processBundle(attributes);
+				break;
+			case ARCHIVE:
+				stateStack.push(Integer.valueOf(STATE_ARCHIVE));
+				processArchive(attributes);
+				break;
+			case CATEGORY_DEF:
+				stateStack.push(Integer.valueOf(STATE_CATEGORY_DEF));
+				processCategoryDef(attributes);
+				break;
+			case CATEGORY:
+				stateStack.push(Integer.valueOf(STATE_CATEGORY));
+				processCategory(attributes);
+				break;
+			default:
+				internalErrorUnknownTag(NLS.bind(Messages.DefaultSiteParser_UnknownElement, (new String[] {elementName, getState(currentState)})));
+				break;
+		}
 	}
 
 	private void handleFeatureState(String elementName, Attributes attributes) {
-		if (elementName.equals(DESCRIPTION)) {
-			stateStack.push(Integer.valueOf(STATE_DESCRIPTION_SITE));
-			processInfo(attributes);
-		} else if (elementName.equals(FEATURE)) {
-			stateStack.push(Integer.valueOf(STATE_FEATURE));
-			processFeature(attributes);
-		} else if (elementName.equals(ARCHIVE)) {
-			stateStack.push(Integer.valueOf(STATE_ARCHIVE));
-			processArchive(attributes);
-		} else if (elementName.equals(CATEGORY_DEF)) {
-			stateStack.push(Integer.valueOf(STATE_CATEGORY_DEF));
-			processCategoryDef(attributes);
-		} else if (elementName.equals(CATEGORY)) {
-			stateStack.push(Integer.valueOf(STATE_CATEGORY));
-			processCategory(attributes);
-		} else
-			internalErrorUnknownTag(NLS.bind(Messages.DefaultSiteParser_UnknownElement, (new String[] {elementName, getState(currentState)})));
+		switch (elementName) {
+			case DESCRIPTION:
+				stateStack.push(Integer.valueOf(STATE_DESCRIPTION_SITE));
+				processInfo(attributes);
+				break;
+			case FEATURE:
+				stateStack.push(Integer.valueOf(STATE_FEATURE));
+				processFeature(attributes);
+				break;
+			case ARCHIVE:
+				stateStack.push(Integer.valueOf(STATE_ARCHIVE));
+				processArchive(attributes);
+				break;
+			case CATEGORY_DEF:
+				stateStack.push(Integer.valueOf(STATE_CATEGORY_DEF));
+				processCategoryDef(attributes);
+				break;
+			case CATEGORY:
+				stateStack.push(Integer.valueOf(STATE_CATEGORY));
+				processCategory(attributes);
+				break;
+			default:
+				internalErrorUnknownTag(NLS.bind(Messages.DefaultSiteParser_UnknownElement, (new String[] {elementName, getState(currentState)})));
+				break;
+		}
 	}
 
 	private void handleBundleState(String elementName, Attributes attributes) {
-		if (elementName.equals(DESCRIPTION)) {
-			stateStack.push(Integer.valueOf(STATE_DESCRIPTION_SITE));
-			processInfo(attributes);
-		} else if (elementName.equals(ARCHIVE)) {
-			stateStack.push(Integer.valueOf(STATE_ARCHIVE));
-			processArchive(attributes);
-		} else if (elementName.equals(CATEGORY_DEF)) {
-			stateStack.push(Integer.valueOf(STATE_CATEGORY_DEF));
-			processCategoryDef(attributes);
-		} else if (elementName.equals(CATEGORY)) {
-			stateStack.push(Integer.valueOf(STATE_CATEGORY));
-			processCategory(attributes);
-		} else
-			internalErrorUnknownTag(NLS.bind(Messages.DefaultSiteParser_UnknownElement, (new String[] {elementName, getState(currentState)})));
+		switch (elementName) {
+			case DESCRIPTION:
+				stateStack.push(Integer.valueOf(STATE_DESCRIPTION_SITE));
+				processInfo(attributes);
+				break;
+			case ARCHIVE:
+				stateStack.push(Integer.valueOf(STATE_ARCHIVE));
+				processArchive(attributes);
+				break;
+			case CATEGORY_DEF:
+				stateStack.push(Integer.valueOf(STATE_CATEGORY_DEF));
+				processCategoryDef(attributes);
+				break;
+			case CATEGORY:
+				stateStack.push(Integer.valueOf(STATE_CATEGORY));
+				processCategory(attributes);
+				break;
+			default:
+				internalErrorUnknownTag(NLS.bind(Messages.DefaultSiteParser_UnknownElement, (new String[] {elementName, getState(currentState)})));
+				break;
+		}
 	}
 
 	private void handleInitialState(String elementName, Attributes attributes) throws SAXException {
@@ -469,23 +504,31 @@ public class DefaultSiteParser extends DefaultHandler {
 	}
 
 	private void handleSiteState(String elementName, Attributes attributes) {
-		if (elementName.equals(DESCRIPTION)) {
-			stateStack.push(Integer.valueOf(STATE_DESCRIPTION_SITE));
-			processInfo(attributes);
-		} else if (elementName.equals(FEATURE)) {
-			stateStack.push(Integer.valueOf(STATE_FEATURE));
-			processFeature(attributes);
-		} else if (elementName.equals(BUNDLE)) {
-			stateStack.push(Integer.valueOf(STATE_BUNDLE));
-			processBundle(attributes);
-		} else if (elementName.equals(ARCHIVE)) {
-			stateStack.push(Integer.valueOf(STATE_ARCHIVE));
-			processArchive(attributes);
-		} else if (elementName.equals(CATEGORY_DEF)) {
-			stateStack.push(Integer.valueOf(STATE_CATEGORY_DEF));
-			processCategoryDef(attributes);
-		} else
-			internalErrorUnknownTag(NLS.bind(Messages.DefaultSiteParser_UnknownElement, (new String[] {elementName, getState(currentState)})));
+		switch (elementName) {
+			case DESCRIPTION:
+				stateStack.push(Integer.valueOf(STATE_DESCRIPTION_SITE));
+				processInfo(attributes);
+				break;
+			case FEATURE:
+				stateStack.push(Integer.valueOf(STATE_FEATURE));
+				processFeature(attributes);
+				break;
+			case BUNDLE:
+				stateStack.push(Integer.valueOf(STATE_BUNDLE));
+				processBundle(attributes);
+				break;
+			case ARCHIVE:
+				stateStack.push(Integer.valueOf(STATE_ARCHIVE));
+				processArchive(attributes);
+				break;
+			case CATEGORY_DEF:
+				stateStack.push(Integer.valueOf(STATE_CATEGORY_DEF));
+				processCategoryDef(attributes);
+				break;
+			default:
+				internalErrorUnknownTag(NLS.bind(Messages.DefaultSiteParser_UnknownElement, (new String[] {elementName, getState(currentState)})));
+				break;
+		}
 	}
 
 	/*
